Package: RcmdrPlugin.UCA
Type: Package
Title: UCA Rcmdr Plug-in
Version: 5.1-4
Date: 2026-05-04
Authors@R: person(given = "Manuel",
   family = "Munoz-Marquez",
   role = c("aut", "cre"),
   email = "manuel.munoz@uca.es")
Depends: IQCC, qcc, qicharts2, randtests, rmarkdown, TeachingDemos,
        tseries
Suggests: car, carData, knitr
VignetteBuilder: knitr
Imports: Rcmdr (>= 1.6)
Description: Some extensions to Rcmdr (R Commander), randomness test, 
 variance test for one normal sample and predictions using active model, 
 made by R-UCA project and used in teaching statistics at University of Cadiz (UCA).
License: GPL (>= 3)
URL: http://knuth.uca.es/RcmdrPlugin.UCA/
NeedsCompilation: no
Packaged: 2026-05-03 16:30:11 UTC; mmarquez
Author: Manuel Munoz-Marquez [aut, cre]
Maintainer: Manuel Munoz-Marquez <manuel.munoz@uca.es>
Repository: CRAN
Date/Publication: 2026-05-03 17:10:02 UTC
Built: R 4.6.0; ; 2026-05-03 19:58:15 UTC; unix
