import('IQCC')
#import("pwr")
import('qcc')
import("Rcmdr")
# The next package is required to build vignettes
import("rmarkdown")

importFrom("qicharts2", "paretochart")
importFrom("randtests", randtest.runs.test = "runs.test")
importFrom("utils", "browseURL")
importFrom("TeachingDemos", "sigma.test")
importFrom("tcltk", "tkbutton")
importFrom("tseries", tseries.runs.test = "runs.test")

### Models
export("input2predict")
export("predict4dataset")

### Quality control
export("cchart1Menu")
export("cchart2Menu")
export("cchartpMenu")
export("npchart1Menu")
export("npchart2Menu")
export("npchartpMenu")
export("paretochartMenu")
export("pchart1Menu")
export("pchart2Menu")
export("pchartpMenu")
export("R1mcMenu")
export("R2mcMenu")
export("RpmcMenu")
export("S1mcMenu")
export("S2mcMenu")
export("SpmcMenu")
export("uchart1Menu")
export("uchart2Menu")
export("uchartpMenu")
export("xbar1mcMenu")
export("xbar2mcMenu")
export("xbarpmcMenu")
export("xbarone1Menu")

### Statistics
export("randomnessFTest")
export("randomnessNTest")
export("twolevelfactor.runs.test")
export("SampleSizeZMenu")
export("sigmaTest")
export("numeric.runs.test")

### Help
export("browseRUCAWebsite")
export("browseRcmdrPluginUCA")
export("checkRUCAversion")
